StructuredValue constant
IriTerm
const StructuredValue
IRI for schemahttp:StructuredValue
Structured values are used when the value of a property has a more complex structure than simply being a textual value or a reference to another thing.
Implementation
static const StructuredValue = const IriTerm(
'http://schema.org/StructuredValue',
);